Module: Google::Cloud::Video::Stitcher

Defined in:
lib/google/cloud/video/stitcher.rb,
lib/google/cloud/video/stitcher/version.rb

Constant Summary collapse

VERSION =
"1.3.0"

Class Method Summary collapse

Class Method Details

.configure {|::Google::Cloud.configure.video_stitcher| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-video-stitcher library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    • :initial_delay (type: Numeric) - The initial delay in seconds.
    • :max_delay (type: Numeric) - The max delay in seconds.
    • :multiplier (type: Numeric) - The incremental backoff multiplier.
    • :jitter (type: Numeric) - The jitter in seconds. Default: 1.0.
    • :retry_codes (type: Array<String>) - The error codes that should trigger a retry.

Yields:

Returns:

  • (::Google::Cloud::Config)

    The default configuration used by this library



143
144
145
146
147
# File 'lib/google/cloud/video/stitcher.rb', line 143

def self.configure
  yield ::Google::Cloud.configure.video_stitcher if block_given?

  ::Google::Cloud.configure.video_stitcher
end

.video_stitcher_service(version: :v1, &block) ⇒ ::Object

Create a new client object for VideoStitcherService.

By default, this returns an instance of Google::Cloud::Video::Stitcher::V1::VideoStitcherService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the VideoStitcherService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

Raises an exception if the currently installed versioned client gem for the given API version does not support the VideoStitcherService service. You can determine whether the method will succeed by calling video_stitcher_service_available?.

About VideoStitcherService

Video-On-Demand content stitching API allows you to insert ads into (VoD) video on demand files. You will be able to render custom scrubber bars with highlighted ads, enforce ad policies, allow seamless playback and tracking on native players and monetize content with any standard VMAP compliant ad server.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object)

    A client object for the specified version.



77
78
79
80
81
82
83
84
85
86
# File 'lib/google/cloud/video/stitcher.rb', line 77

def self.video_stitcher_service version: :v1, &block
  require "google/cloud/video/stitcher/#{version.to_s.downcase}"

  package_name = Google::Cloud::Video::Stitcher
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::Video::Stitcher.const_get(package_name).const_get(:VideoStitcherService)
  service_module.const_get(:Client).new(&block)
end

.video_stitcher_service_available?(version: :v1) ⇒ boolean

Determines whether the VideoStitcherService service is supported by the current client. If true, you can retrieve a client object by calling video_stitcher_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the VideoStitcherService service, or if the versioned client gem needs an update to support the VideoStitcherService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (boolean)

    Whether the service is available.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/google/cloud/video/stitcher.rb', line 99

def self.video_stitcher_service_available? version: :v1
  require "google/cloud/video/stitcher/#{version.to_s.downcase}"
  package_name = Google::Cloud::Video::Stitcher
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::Video::Stitcher.const_get package_name
  return false unless service_module.const_defined? :VideoStitcherService
  service_module = service_module.const_get :VideoStitcherService
  service_module.const_defined? :Client
rescue ::LoadError
  false
end